@@ -11,6 +11,8 @@ use CPAN::Meta::Requirements;
 use Perl::PrereqScanner::NotQuiteLite;
 use Perl::PrereqScanner::NotQuiteLite::Util::Prereqs;
 
+use constant WIN32 => $^O eq 'MSWin32';
+
 my %IsTestClassFamily = map {$_ => 1} qw(
   Test::Class
   Test::Class::Moose
@@ -46,9 +48,13 @@ sub new {
     my %map;
     for my $spec (@features) {
       my ($identifier, $description, $paths) = split ':', $spec;
+      my @paths = map { bsd_glob(File::Spec->catdir($opts{base_dir}, $_)) } split ',', $paths;
+      if (WIN32) {
+          s|\\|/|g for @paths;
+      }
       $map{$identifier} = {
         description => $description,
-        paths => [map { bsd_glob(File::Spec->catdir($opts{base_dir}, $_)) } split ',', $paths],
+        paths => \@paths,
       };
     }
     $opts{features} = \%map;
@@ -58,7 +64,7 @@ sub new {
     require Regexp::Trie;
     my $re = Regexp::Trie->new;
     for (@{$opts{ignore}}) {
-        s|\\|/|g if $^O eq 'MSWin32';
+        s|\\|/|g if WIN32;
         $re->add($_);
     }
     $opts{ignore_re} ||= $re->_regexp;
@@ -154,10 +160,11 @@ sub run {
 
       if ($self->{save_cpanfile}) {
         $cpanfile->save($file);
-      } else {
+      } elsif ($self->{print}) {
         print $cpanfile->to_string, "\n";
       }
-    } else {
+      return $cpanfile;
+    } elsif ($self->{print}) {
       $self->_print_prereqs;
     }
   }
@@ -410,8 +417,8 @@ sub _scan_dir {
 sub _scan_file {
   my ($self, $file) = @_;
 
+  $file =~ s|\\|/|g if WIN32;
   if ($self->{ignore_re}) {
-    $file =~ s|\\|/|g if $^O eq 'MSWin32';
     return if $file =~ /\b$self->{ignore_re}\b/;
   }
 
@@ -423,7 +430,7 @@ sub _scan_file {
   )->scan_file($file);
 
   my $relpath = File::Spec->abs2rel($file, $self->{base_dir});
-  $relpath =~ s|\\|/|g if $^O eq 'MSWin32';
+  $relpath =~ s|\\|/|g if WIN32;
 
   my $prereqs = $self->{prereqs};
   if ($self->{features}) {
